### R code from vignette source 'LaplacesDemonTutorial.Stex'

###################################################
### code chunk number 1: LaplacesDemonTutorial.Stex:63-64 (eval = FALSE)
###################################################
## install.packages("LaplacesDemon")


###################################################
### code chunk number 2: LaplacesDemonTutorial.Stex:69-70
###################################################
library(LaplacesDemon)


###################################################
### code chunk number 3: LaplacesDemonTutorial.Stex:76-87
###################################################
data(demonsnacks)
N <- nrow(demonsnacks)
y <- log(demonsnacks$Calories)
X <- cbind(1, as.matrix(log(demonsnacks[,c(1,4,10)]+1)))
J <- ncol(X)
for (j in 2:J) {X[,j] <- CenterScale(X[,j])}
mon.names <- c("LP","sigma")
parm.names <- as.parm.names(list(beta=rep(0,J), log.sigma=0))
PGF <- function(Data) return(c(rnormv(Data$J,0,10), log(rhalfcauchy(1,25))))
MyData <- list(J=J, PGF=PGF, X=X, mon.names=mon.names, 
     parm.names=parm.names, y=y)


###################################################
### code chunk number 4: LaplacesDemonTutorial.Stex:113-130
###################################################
Model <- function(parm, Data)
     {
     ### Parameters
     beta <- parm[1:Data$J]
     sigma <- exp(parm[Data$J+1])
     ### Log(Prior Densities)
     beta.prior <- dnormv(beta, 0, 1000, log=TRUE)
     sigma.prior <- dhalfcauchy(sigma, 25, log=TRUE)
     ### Log-Likelihood
     mu <- tcrossprod(beta, Data$X)
     LL <- sum(dnorm(Data$y, mu, sigma, log=TRUE))
     ### Log-Posterior
     LP <- LL + sum(beta.prior) + sigma.prior
     Modelout <- list(LP=LP, Dev=-2*LL, Monitor=c(LP,sigma),
          yhat=rnorm(length(mu), mu, sigma), parm=parm)
     return(Modelout)
     }


###################################################
### code chunk number 5: LaplacesDemonTutorial.Stex:191-192
###################################################
Initial.Values <- c(rep(0,J), log(1))


###################################################
### code chunk number 6: LaplacesDemonTutorial.Stex:198-199
###################################################
set.seed(666)


###################################################
### code chunk number 7: LaplacesDemonTutorial.Stex:204-205 (eval = FALSE)
###################################################
## help(LaplacesDemon) 


###################################################
### code chunk number 8: LaplacesDemonTutorial.Stex:210-213 (eval = FALSE)
###################################################
## Fit <- LaplacesDemon(Model, Data=MyData, Initial.Values,
##      Covar=NULL, Iterations=150000, Status=50000, Thinning=150,
##      Algorithm="HARM", Specs=NULL)


###################################################
### code chunk number 9: LaplacesDemonTutorial.Stex:231-234
###################################################
Fit <- LaplacesDemon(Model, Data=MyData, Initial.Values,
     Covar=NULL, Iterations=150000, Status=50000, Thinning=150,
     Algorithm="HARM", Specs=NULL)


###################################################
### code chunk number 10: LaplacesDemonTutorial.Stex:239-240 (eval = FALSE)
###################################################
## str(Fit)


###################################################
### code chunk number 11: LaplacesDemonTutorial.Stex:245-246
###################################################
Fit$Acceptance.Rate


###################################################
### code chunk number 12: LaplacesDemonTutorial.Stex:257-259 (eval = FALSE)
###################################################
## Fit
## print(Fit)


###################################################
### code chunk number 13: LaplacesDemonTutorial.Stex:264-265
###################################################
Consort(Fit)


###################################################
### code chunk number 14: LaplacesDemonTutorial.Stex:270-271 (eval = FALSE)
###################################################
## Fit$Posterior2


###################################################
### code chunk number 15: LaplacesDemonTutorial.Stex:293-293
###################################################



###################################################
### code chunk number 16: LaplacesDemonTutorial.Stex:295-296 (eval = FALSE)
###################################################
## plot(Fit, BurnIn=1, MyData, PDF=FALSE, Parms=NULL)


###################################################
### code chunk number 17: fig1
###################################################
par(mfrow=c(3,3))
BurnIn <- 1
for (j in 1:3){
     plot(BurnIn:Fit$Thinned.Samples,
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j],
          type="l", xlab="Iterations", ylab="Value",
          main=MyData$parm.names[j])
     panel.smooth(BurnIn:Fit$Thinned.Samples, 
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], pch="")
     plot(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          xlab="Value", main=MyData$parm.names[j])
     polygon(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$parm.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }


###################################################
### code chunk number 18: fig2
###################################################
par(mfrow=c(3,3))
for (j in 4:5){
     plot(BurnIn:Fit$Thinned.Samples,
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j],
          type="l", xlab="Iterations", ylab="Value",
          main=MyData$parm.names[j])
     panel.smooth(BurnIn:Fit$Thinned.Samples, 
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], pch="")
     plot(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          xlab="Value", main=MyData$parm.names[j])
     polygon(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$parm.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }
plot(BurnIn:length(Fit$Deviance),
     Fit$Deviance[BurnIn:length(Fit$Deviance)],
     type="l", xlab="Iterations", ylab="Value", main="Deviance")
panel.smooth(BurnIn:length(Fit$Deviance), 
     Fit$Deviance[BurnIn:length(Fit$Deviance)], pch="")
plot(density(Fit$Deviance[BurnIn:length(Fit$Deviance)]),
     xlab="Value", main="Deviance")
polygon(density(Fit$Deviance[BurnIn:length(Fit$Deviance)]),
     col="black", border="black")
abline(v=0, col="red", lty=2)
z <- acf(Fit$Deviance[BurnIn:length(Fit$Deviance)], plot=FALSE)
se <- 1/sqrt(length(Fit$Deviance[BurnIn:length(Fit$Deviance)]))
plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
     main="Deviance", xlab="Lag", ylab="Correlation")
abline(h=(2*se), col="red", lty=2)
abline(h=(-2*se), col="red", lty=2)


###################################################
### code chunk number 19: fig3
###################################################
par(mfrow=c(2,3))
JJ <- NCOL(Fit$Monitor); nn <- NROW(Fit$Monitor)
for (j in 1:JJ){
     plot(BurnIn:nn, 
          Fit$Monitor[BurnIn:nn,j],
          type="l", xlab="Iterations", ylab="Value", 
          main=MyData$mon.names[j])
     panel.smooth(BurnIn:nn, 
          Fit$Monitor[BurnIn:nn,j], pch="")
     plot(density(Fit$Monitor[BurnIn:nn,j]), xlab="Value", 
          main=MyData$mon.names[j])
     polygon(density(Fit$Monitor[BurnIn:nn,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Monitor[BurnIn:nn,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Monitor[BurnIn:nn,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$mon.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }


###################################################
### code chunk number 20: LaplacesDemonTutorial.Stex:408-409 (eval = FALSE)
###################################################
## plot(BMK.Diagnostic(Fit))


###################################################
### code chunk number 21: fig4
###################################################
par(mfrow=c(1,1))
plot(BMK.Diagnostic(Fit))


###################################################
### code chunk number 22: LaplacesDemonTutorial.Stex:426-427 (eval = FALSE)
###################################################
## caterpillar.plot(Fit, Parms=1:4)


###################################################
### code chunk number 23: fig5
###################################################
par(mfrow=c(1,1))
caterpillar.plot(Fit, Parms=1:4)


###################################################
### code chunk number 24: LaplacesDemonTutorial.Stex:445-446
###################################################
Pred <- predict(Fit, Model, MyData)


###################################################
### code chunk number 25: LaplacesDemonTutorial.Stex:455-456
###################################################
summary(Pred, Discrep="Chi-Square")


###################################################
### code chunk number 26: LaplacesDemonTutorial.Stex:470-471 (eval = FALSE)
###################################################
## plot(Pred, Style="Density", Rows=1:9)


###################################################
### code chunk number 27: fig6
###################################################
par(mfrow=c(3,3))
for (j in 1:9){
     plot(density(Pred$yhat[j,]), xlab="Value",
          main=paste("Post. Pred. Plot of yhat[", j,
               ",]", sep=""), sub="Black=Density, Red=y")
     polygon(density(Pred$yhat[j,]), col="black", border="black")
     abline(v=Pred$y[j], col="red")
     }


###################################################
### code chunk number 28: LaplacesDemonTutorial.Stex:492-493 (eval = FALSE)
###################################################
## plot(Pred, Style="Fitted")


###################################################
### code chunk number 29: fig7
###################################################
par(mfrow=c(1,1))
temp <- summary(Pred, Quiet=TRUE)$Summary
plot(temp[,1], temp[,5], pch=16, cex=0.75,
     ylim=c(min(temp[,c(1,4:6)], na.rm=TRUE),
          max(temp[,c(1,4:6)], na.rm=TRUE)),
     xlab="y", ylab="yhat", main="Fitted")
for (i in 1:length(y)) {
     lines(c(temp[i,1], temp[i,1]),
          c(temp[i,4], temp[i,6]))}
panel.smooth(temp[,1], temp[,5], pch=16, cex=0.75)


###################################################
### code chunk number 30: LaplacesDemonTutorial.Stex:551-552 (eval = FALSE)
###################################################
## LaplacesDemon


###################################################
### code chunk number 31: LaplacesDemonTutorial.Stex:557-558 (eval = FALSE)
###################################################
## LaplacesDemon:::RWM


